import Taro, { Component } from '@tarojs/taro'
import { View, ScrollView, Button, Swiper } from '@tarojs/components'
import Unit from '../../components/HouseGrid/Unit'
import NamedIcon from '../../components/NamedIcon'
import ScrollMessage from '../../components/ScrollMessage'
import Blank from '../../components/Blank'
import { formateLeftTime } from '@/utils/tools'

import './index.scss'

export default class HouseList extends Component {
  state = {
    testData: [
      {
        unitId: 2,
        unitName: '2 单元',
        blockId: 1,
        blockName: '1号楼',
        floorList: [
          {
            floorId: 3,
            floorName: '3楼',
            roomList: [
              {
                houseId: 1,
                roomNumber: '301',
                totalNum: 1,
                price: '234万',
                apartmentName: 'A户型'
              },
              {
                houseId: 2,
                roomNumber: '302',
                totalNum: 3,
                price: '234万',
                apartmentName: 'D户型'
              },
              {
                houseId: 3,
                roomNumber: '303',
                totalNum: 0,
                price: '234万',
                apartmentName: 'C户型'
              },
              {
                houseId: 4,
                roomNumber: '304',
                totalNum: 16,
                price: '234万',
                apartmentName: 'B户型'
              },
              {
                houseId: 5,
                roomNumber: '305',
                totalNum: 66,
                price: '234万',
                apartmentName: 'B户型'
              },
              {
                houseId: 6,
                roomNumber: '306',
                totalNum: 266,
                price: '234万',
                apartmentName: 'B户型'
              },
            ]
          },
          {
            floorId: 2,
            floorName: '2楼',
            roomList: [
              {
                houseId: 21,
                roomNumber: '201',
                totalNum: 1,
                price: '234万',
                apartmentName: 'A户型'
              },
              {
                houseId: 22,
                roomNumber: '202',
                totalNum: 3,
                price: '234万',
                apartmentName: 'D户型'
              },
              {
                houseId: 23,
                roomNumber: '203',
                totalNum: 0,
                price: '234万',
                apartmentName: 'C户型'
              },
              {
                houseId: 24,
                roomNumber: '204',
                totalNum: 16,
                price: '234万',
                apartmentName: 'B户型'
              },
            ]
          },
          {
            floorId: 11,
            floorName: '1楼',
            roomList: [
              {
                houseId: 11,
                roomNumber: '101',
                totalNum: 1,
                price: '234万',
                apartmentName: 'A户型'
              },
              {
                houseId: 12,
                roomNumber: '102',
                totalNum: 3,
                price: '234万',
                apartmentName: 'D户型'
              },
              {
                houseId: 13,
                roomNumber: '103',
                totalNum: 0,
                price: '234万',
                apartmentName: 'C户型'
              },
              {
                houseId: 14,
                roomNumber: '104',
                totalNum: 16,
                price: '234万',
                apartmentName: 'B户型'
              },
              {
                houseId: 15,
                roomNumber: '105',
                totalNum: 0,
                price: '234万',
                apartmentName: 'C户型'
              },
              {
                houseId: 16,
                roomNumber: '106',
                totalNum: 16,
                price: '234万',
                apartmentName: 'B户型'
              },
            ]
          }
        ]
      },
      {
        unitId: 11,
        unitName: '1 单元',
        blockId: 2,
        blockName: '2号楼',
        floorList: [
          {
            floorId: 3,
            floorName: '3楼',
            roomList: [
              {
                houseId: 1,
                roomNumber: '301',
                totalNum: 1,
                price: '234万',
                apartmentName: 'A户型'
              },
              {
                houseId: 2,
                roomNumber: '302',
                totalNum: 3,
                price: '234万',
                apartmentName: 'D户型'
              },
              {
                houseId: 3,
                roomNumber: '303',
                totalNum: 0,
                price: '234万',
                apartmentName: 'C户型'
              },
              {
                houseId: 4,
                roomNumber: '304',
                totalNum: 16,
                price: '234万',
                apartmentName: 'B户型'
              },
            ]
          }
        ]
      }
    ]
  }

  goto = url => Taro.navigateTo({ url })

  handleExplainClick = e => {
    this.goto('/onlineSelling/pages/help/index')
  }

  handleSearchClick = e => {}

  renderBar () {
    const summary = {
      preselectionStartTime: '2020-02-09',
      preselectionEndTime: '2020-02-16',
      salesNumber: 199,
      preselectionNumber: 16,
    }

    return (
      <View className="topbar">
        <View className="body">
          <ScrollMessage summary={summary} />
        </View>
        <View className="action">
          <View onClick={this.handleExplainClick}>
            <NamedIcon name="explain" size={50} />
          </View>
          <View onClick={this.handleSearchClick}>
            <NamedIcon name="screen" size={50} />
          </View>
        </View>
      </View>
    )
  }

  renderHouses() {
    const { testData } = this.state

    return (
      <ScrollView className="container" scrollY scrollWithAnimation>
      {
        testData.map((item) => {
          return <Unit key={item.unitId} dataset={item} />
        })
      }
      </ScrollView>
    )
  }

  renderBlank() {
    return (
      <View className="container"><Blank /></View>      
    )
  }

  renderBottom() {
    return (
      <View className="bottombar">
        <Button className="btn record">
          <NamedIcon name="record" size="42"/>
          <Text className="txt">选房记录</Text>
        </Button>
        <Button className="btn share">
          <NamedIcon name="share" size="42"/>
          <Text className="txt">分享</Text>
        </Button>
      </View>
    )
  }

  render () {
    return (
      <View className="houselist">
        {this.renderBar()}
        {this.renderHouses()}
        {/* {this.renderBlank()} */}
        {this.renderBottom()}
      </View>
    )
  }
}

